@@ -36,10 +36,12 @@ public final class Tagger {
 	int start=0;
 	for(int i=tmpRlt.size()-1; i >=0; i--) {
 	    final ViterbiNode vn = tmpRlt.get(i);
-	    final String surface = text.substring(start, start+vn.length);
-	    final String info    = wdc.wordData(vn.wordId);
 	    start += vn.length;
+	    if(vn.isSpace)
+		continue;
 	    
+	    final String surface = text.substring(start-vn.length, start);
+	    final String info    = wdc.wordData(vn.wordId);
 	    result.add(new Morpheme(surface, info));
 	}
     }
@@ -56,8 +58,10 @@ public final class Tagger {
 	int start=0;
 	for(int i=tmpRlt.size()-1; i >=0; i--) {
 	    final ViterbiNode vn = tmpRlt.get(i);
-	    result.add(text.substring(start, start+vn.length));
 	    start += vn.length;
+	    if(vn.isSpace)
+		continue;
+	    result.add(text.substring(start-vn.length, start));
 	}	
     }
     
